# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.main.community.reply.v1 import reply_pb2 as bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2


class ReplyStub(object):
    """评论区
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.MainList = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/MainList',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.MainListReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.MainListReply.FromString,
                )
        self.DetailList = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/DetailList',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DetailListReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DetailListReply.FromString,
                )
        self.DialogList = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/DialogList',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DialogListReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DialogListReply.FromString,
                )
        self.PreviewList = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/PreviewList',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.PreviewListReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.PreviewListReply.FromString,
                )
        self.SearchItemPreHook = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/SearchItemPreHook',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemPreHookReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemPreHookReply.FromString,
                )
        self.SearchItem = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/SearchItem',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemReply.FromString,
                )
        self.AtSearch = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/AtSearch',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.AtSearchReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.AtSearchReply.FromString,
                )
        self.ReplyInfo = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/ReplyInfo',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ReplyInfoReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ReplyInfoReply.FromString,
                )
        self.UserCallback = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/UserCallback',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.UserCallbackReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.UserCallbackReply.FromString,
                )
        self.ShareRepliesInfo = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/ShareRepliesInfo',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ShareRepliesInfoReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ShareRepliesInfoResp.FromString,
                )
        self.SuggestEmotes = channel.unary_unary(
                '/bilibili.main.community.reply.v1.Reply/SuggestEmotes',
                request_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SuggestEmotesReq.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SuggestEmotesResp.FromString,
                )


class ReplyServicer(object):
    """评论区
    """

    def MainList(self, request, context):
        """主评论列表接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DetailList(self, request, context):
        """二级评论明细接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DialogList(self, request, context):
        """对话评论树接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PreviewList(self, request, context):
        """评论预览接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchItemPreHook(self, request, context):
        """评论搜索item前置发布接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchItem(self, request, context):
        """评论搜索插入项目接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AtSearch(self, request, context):
        """评论at用户搜索接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReplyInfo(self, request, context):
        """查询单条评论接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UserCallback(self, request, context):
        """用户回调上报接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShareRepliesInfo(self, request, context):
        """评论分享材料接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SuggestEmotes(self, request, context):
        """评论表情推荐列表接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ReplyServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'MainList': grpc.unary_unary_rpc_method_handler(
                    servicer.MainList,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.MainListReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.MainListReply.SerializeToString,
            ),
            'DetailList': grpc.unary_unary_rpc_method_handler(
                    servicer.DetailList,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DetailListReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DetailListReply.SerializeToString,
            ),
            'DialogList': grpc.unary_unary_rpc_method_handler(
                    servicer.DialogList,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DialogListReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DialogListReply.SerializeToString,
            ),
            'PreviewList': grpc.unary_unary_rpc_method_handler(
                    servicer.PreviewList,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.PreviewListReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.PreviewListReply.SerializeToString,
            ),
            'SearchItemPreHook': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchItemPreHook,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemPreHookReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemPreHookReply.SerializeToString,
            ),
            'SearchItem': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchItem,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemReply.SerializeToString,
            ),
            'AtSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.AtSearch,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.AtSearchReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.AtSearchReply.SerializeToString,
            ),
            'ReplyInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.ReplyInfo,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ReplyInfoReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ReplyInfoReply.SerializeToString,
            ),
            'UserCallback': grpc.unary_unary_rpc_method_handler(
                    servicer.UserCallback,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.UserCallbackReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.UserCallbackReply.SerializeToString,
            ),
            'ShareRepliesInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.ShareRepliesInfo,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ShareRepliesInfoReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ShareRepliesInfoResp.SerializeToString,
            ),
            'SuggestEmotes': grpc.unary_unary_rpc_method_handler(
                    servicer.SuggestEmotes,
                    request_deserializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SuggestEmotesReq.FromString,
                    response_serializer=bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SuggestEmotesResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.main.community.reply.v1.Reply', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Reply(object):
    """评论区
    """

    @staticmethod
    def MainList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/MainList',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.MainListReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.MainListReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DetailList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/DetailList',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DetailListReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DetailListReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DialogList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/DialogList',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DialogListReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.DialogListReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PreviewList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/PreviewList',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.PreviewListReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.PreviewListReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchItemPreHook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/SearchItemPreHook',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemPreHookReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemPreHookReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchItem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/SearchItem',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SearchItemReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AtSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/AtSearch',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.AtSearchReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.AtSearchReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReplyInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/ReplyInfo',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ReplyInfoReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ReplyInfoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UserCallback(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/UserCallback',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.UserCallbackReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.UserCallbackReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShareRepliesInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/ShareRepliesInfo',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ShareRepliesInfoReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.ShareRepliesInfoResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SuggestEmotes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.community.reply.v1.Reply/SuggestEmotes',
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SuggestEmotesReq.SerializeToString,
            bilibili_dot_main_dot_community_dot_reply_dot_v1_dot_reply__pb2.SuggestEmotesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.app.distribution.v1 import distribution_pb2 as bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2


class DistributionStub(object):
    """APP配置
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUserPreference = channel.unary_unary(
                '/bilibili.app.distribution.v1.Distribution/GetUserPreference',
                request_serializer=bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.GetUserPreferenceReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.GetUserPreferenceReply.FromString,
                )
        self.SetUserPreference = channel.unary_unary(
                '/bilibili.app.distribution.v1.Distribution/SetUserPreference',
                request_serializer=bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.SetUserPreferenceReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.SetUserPreferenceReply.FromString,
                )
        self.UserPreference = channel.unary_unary(
                '/bilibili.app.distribution.v1.Distribution/UserPreference',
                request_serializer=bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.UserPreferenceReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.UserPreferenceReply.FromString,
                )


class DistributionServicer(object):
    """APP配置
    """

    def GetUserPreference(self, request, context):
        """获取云端储存的用户偏好
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetUserPreference(self, request, context):
        """设定用户偏好
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UserPreference(self, request, context):
        """获取云控配置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DistributionServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetUserPreference': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserPreference,
                    request_deserializer=bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.GetUserPreferenceReq.FromString,
                    response_serializer=bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.GetUserPreferenceReply.SerializeToString,
            ),
            'SetUserPreference': grpc.unary_unary_rpc_method_handler(
                    servicer.SetUserPreference,
                    request_deserializer=bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.SetUserPreferenceReq.FromString,
                    response_serializer=bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.SetUserPreferenceReply.SerializeToString,
            ),
            'UserPreference': grpc.unary_unary_rpc_method_handler(
                    servicer.UserPreference,
                    request_deserializer=bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.UserPreferenceReq.FromString,
                    response_serializer=bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.UserPreferenceReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.app.distribution.v1.Distribution', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Distribution(object):
    """APP配置
    """

    @staticmethod
    def GetUserPreference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.distribution.v1.Distribution/GetUserPreference',
            bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.GetUserPreferenceReq.SerializeToString,
            bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.GetUserPreferenceReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetUserPreference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.distribution.v1.Distribution/SetUserPreference',
            bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.SetUserPreferenceReq.SerializeToString,
            bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.SetUserPreferenceReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UserPreference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.distribution.v1.Distribution/UserPreference',
            bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.UserPreferenceReq.SerializeToString,
            bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2.UserPreferenceReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import bilireq.grpc.protos.bilibili.app.archive.v1.archive_pb2
import bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _From:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FromEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_From.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ArchiveTab: _From.ValueType  # 0
    """"""
    DynamicTab: _From.ValueType  # 1
    """"""

class From(_From, metaclass=_FromEnumTypeWrapper): ...

ArchiveTab: From.ValueType  # 0
""""""
DynamicTab: From.ValueType  # 1
""""""
global___From = From

@typing_extensions.final
class Arc(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARCHIVE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    @property
    def archive(self) -> bilireq.grpc.protos.bilibili.app.archive.v1.archive_pb2.Arc:
        """"""
    uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        archive: bilireq.grpc.protos.bilibili.app.archive.v1.archive_pb2.Arc | None = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["archive", b"archive"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["archive", b"archive", "uri", b"uri"]) -> None: ...

global___Arc = Arc

@typing_extensions.final
class Dynamic(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYNAMIC_FIELD_NUMBER: builtins.int
    @property
    def dynamic(self) -> bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2.DynamicItem:
        """"""
    def __init__(
        self,
        *,
        dynamic: bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2.DynamicItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dynamic", b"dynamic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic", b"dynamic"]) -> None: ...

global___Dynamic = Dynamic

@typing_extensions.final
class SearchTabReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOCUS_FIELD_NUMBER: builtins.int
    TABS_FIELD_NUMBER: builtins.int
    focus: builtins.int
    """"""
    @property
    def tabs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Tab]:
        """"""
    def __init__(
        self,
        *,
        focus: builtins.int = ...,
        tabs: collections.abc.Iterable[global___Tab] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["focus", b"focus", "tabs", b"tabs"]) -> None: ...

global___SearchTabReply = SearchTabReply

@typing_extensions.final
class SearchTabReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYWORD_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    keyword: builtins.str
    """"""
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        keyword: builtins.str = ...,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from", b"from", "keyword", b"keyword", "mid", b"mid"]) -> None: ...

global___SearchTabReq = SearchTabReq

@typing_extensions.final
class SearchArchiveReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARCHIVES_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    @property
    def archives(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Arc]:
        """"""
    total: builtins.int
    """"""
    def __init__(
        self,
        *,
        archives: collections.abc.Iterable[global___Arc] | None = ...,
        total: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["archives", b"archives", "total", b"total"]) -> None: ...

global___SearchArchiveReply = SearchArchiveReply

@typing_extensions.final
class SearchArchiveReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYWORD_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    PN_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    keyword: builtins.str
    """"""
    mid: builtins.int
    """"""
    pn: builtins.int
    """"""
    ps: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    def __init__(
        self,
        *,
        keyword: builtins.str = ...,
        mid: builtins.int = ...,
        pn: builtins.int = ...,
        ps: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["keyword", b"keyword", "mid", b"mid", "player_args", b"player_args", "pn", b"pn", "ps", b"ps"]) -> None: ...

global___SearchArchiveReq = SearchArchiveReq

@typing_extensions.final
class SearchDynamicReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYNAMICS_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    @property
    def dynamics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Dynamic]:
        """"""
    total: builtins.int
    """"""
    def __init__(
        self,
        *,
        dynamics: collections.abc.Iterable[global___Dynamic] | None = ...,
        total: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamics", b"dynamics", "total", b"total"]) -> None: ...

global___SearchDynamicReply = SearchDynamicReply

@typing_extensions.final
class SearchDynamicReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYWORD_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    PN_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    keyword: builtins.str
    """"""
    mid: builtins.int
    """"""
    pn: builtins.int
    """"""
    ps: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    def __init__(
        self,
        *,
        keyword: builtins.str = ...,
        mid: builtins.int = ...,
        pn: builtins.int = ...,
        ps: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["keyword", b"keyword", "mid", b"mid", "player_args", b"player_args", "pn", b"pn", "ps", b"ps"]) -> None: ...

global___SearchDynamicReq = SearchDynamicReq

@typing_extensions.final
class Tab(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["title", b"title", "uri", b"uri"]) -> None: ...

global___Tab = Tab



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PlayState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PlayStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PlayState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STATE_UNKNOWN: _PlayState.ValueType  # 0
    """"""
    PREPARING: _PlayState.ValueType  # 1
    """"""
    PREPARED: _PlayState.ValueType  # 2
    """"""
    PLAYING: _PlayState.ValueType  # 3
    """"""
    PAUSED: _PlayState.ValueType  # 4
    """"""
    STOPPED: _PlayState.ValueType  # 5
    """"""
    FAILED: _PlayState.ValueType  # 6
    """"""

class PlayState(_PlayState, metaclass=_PlayStateEnumTypeWrapper):
    """"""

STATE_UNKNOWN: PlayState.ValueType  # 0
""""""
PREPARING: PlayState.ValueType  # 1
""""""
PREPARED: PlayState.ValueType  # 2
""""""
PLAYING: PlayState.ValueType  # 3
""""""
PAUSED: PlayState.ValueType  # 4
""""""
STOPPED: PlayState.ValueType  # 5
""""""
FAILED: PlayState.ValueType  # 6
""""""
global___PlayState = PlayState

class _Stage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Stage.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STAGE_UNKNOWN: _Stage.ValueType  # 0
    """"""
    START: _Stage.ValueType  # 1
    """"""
    END: _Stage.ValueType  # 2
    """"""
    SAMPLE: _Stage.ValueType  # 3
    """"""

class Stage(_Stage, metaclass=_StageEnumTypeWrapper):
    """"""

STAGE_UNKNOWN: Stage.ValueType  # 0
""""""
START: Stage.ValueType  # 1
""""""
END: Stage.ValueType  # 2
""""""
SAMPLE: Stage.ValueType  # 3
""""""
global___Stage = Stage

@typing_extensions.final
class AccountInfo(google.protobuf.message.Message):
    """账户信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid"]) -> None: ...

global___AccountInfo = AccountInfo

@typing_extensions.final
class AppInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOP_PAGE_CLASS_FIELD_NUMBER: builtins.int
    FTIME_FIELD_NUMBER: builtins.int
    DID_FIELD_NUMBER: builtins.int
    top_page_class: builtins.str
    """"""
    ftime: builtins.int
    """客户端首次启动时的毫秒时间戳"""
    did: builtins.str
    """"""
    def __init__(
        self,
        *,
        top_page_class: builtins.str = ...,
        ftime: builtins.int = ...,
        did: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["did", b"did", "ftime", b"ftime", "top_page_class", b"top_page_class"]) -> None: ...

global___AppInfo = AppInfo

@typing_extensions.final
class Extra(google.protobuf.message.Message):
    """心跳补充信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_FIELD_NUMBER: builtins.int
    REFER_FIELD_NUMBER: builtins.int
    session: builtins.str
    """"""
    refer: builtins.str
    """"""
    def __init__(
        self,
        *,
        session: builtins.str = ...,
        refer: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["refer", b"refer", "session", b"session"]) -> None: ...

global___Extra = Extra

@typing_extensions.final
class HeartBeatReply(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___HeartBeatReply = HeartBeatReply

@typing_extensions.final
class HeartBeatReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_V2_FIELD_NUMBER: builtins.int
    STAGE_FIELD_NUMBER: builtins.int
    STREAM_TIMEOUT_FIELD_NUMBER: builtins.int
    BATCH_FREQUENCY_FIELD_NUMBER: builtins.int
    FREQUENCY_FIELD_NUMBER: builtins.int
    VIDEO_META_FIELD_NUMBER: builtins.int
    APP_INFO_FIELD_NUMBER: builtins.int
    ACCOUNT_INFO_FIELD_NUMBER: builtins.int
    PRE_PROCESS_RESULT_FIELD_NUMBER: builtins.int
    PLAYER_STATUS_FIELD_NUMBER: builtins.int
    VIDEO_INFO_FIELD_NUMBER: builtins.int
    session_v2: builtins.str
    """"""
    stage: global___Stage.ValueType
    """"""
    stream_timeout: builtins.int
    """流加载失败timeout"""
    batch_frequency: builtins.int
    """"""
    frequency: builtins.float
    """"""
    @property
    def video_meta(self) -> global___VideoMeta:
        """"""
    @property
    def app_info(self) -> global___AppInfo:
        """"""
    @property
    def account_info(self) -> global___AccountInfo:
        """"""
    @property
    def pre_process_result(self) -> global___PreProcessResult:
        """"""
    @property
    def player_status(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PlayerStatus]:
        """"""
    @property
    def video_info(self) -> global___VideoInfo:
        """"""
    def __init__(
        self,
        *,
        session_v2: builtins.str = ...,
        stage: global___Stage.ValueType = ...,
        stream_timeout: builtins.int = ...,
        batch_frequency: builtins.int = ...,
        frequency: builtins.float = ...,
        video_meta: global___VideoMeta | None = ...,
        app_info: global___AppInfo | None = ...,
        account_info: global___AccountInfo | None = ...,
        pre_process_result: global___PreProcessResult | None = ...,
        player_status: collections.abc.Iterable[global___PlayerStatus] | None = ...,
        video_info: global___VideoInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account_info", b"account_info", "app_info", b"app_info", "pre_process_result", b"pre_process_result", "video_info", b"video_info", "video_meta", b"video_meta"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_info", b"account_info", "app_info", b"app_info", "batch_frequency", b"batch_frequency", "frequency", b"frequency", "player_status", b"player_status", "pre_process_result", b"pre_process_result", "session_v2", b"session_v2", "stage", b"stage", "stream_timeout", b"stream_timeout", "video_info", b"video_info", "video_meta", b"video_meta"]) -> None: ...

global___HeartBeatReq = HeartBeatReq

@typing_extensions.final
class PlayerStatus(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYBACK_RATE_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    PLAY_STATE_FIELD_NUMBER: builtins.int
    IS_BUFFERING_FIELD_NUMBER: builtins.int
    playback_rate: builtins.float
    """"""
    progress: builtins.int
    """"""
    play_state: global___PlayState.ValueType
    """"""
    is_buffering: builtins.bool
    """"""
    def __init__(
        self,
        *,
        playback_rate: builtins.float = ...,
        progress: builtins.int = ...,
        play_state: global___PlayState.ValueType = ...,
        is_buffering: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_buffering", b"is_buffering", "play_state", b"play_state", "playback_rate", b"playback_rate", "progress", b"progress"]) -> None: ...

global___PlayerStatus = PlayerStatus

@typing_extensions.final
class PreProcessResult(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VT_FIELD_NUMBER: builtins.int
    vt: builtins.int
    """"""
    def __init__(
        self,
        *,
        vt: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["vt", b"vt"]) -> None: ...

global___PreProcessResult = PreProcessResult

@typing_extensions.final
class VideoInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CID_DURATION_FIELD_NUMBER: builtins.int
    cid_duration: builtins.int
    """"""
    def __init__(
        self,
        *,
        cid_duration: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid_duration", b"cid_duration"]) -> None: ...

global___VideoInfo = VideoInfo

@typing_extensions.final
class VideoMeta(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    cid: builtins.int
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid"]) -> None: ...

global___VideoMeta = VideoMeta



from typing import Union

from ..utils import get

BASE_URL = "https://api.bilibili.com"


async def get_user_info(uid: Union[int, str], *, auth=None, reqtype="app", **kwargs):
    """根据 UID 获取指定用户信息"""
    url = f"{BASE_URL}/x/space/wbi/acc/info"
    params = {"mid": uid}
    return await get(
        url, params=params, auth=auth, reqtype=reqtype, is_wbi=True, **kwargs
    )


async def get_videos(
    uid: int,
    tid: int = 0,
    pn: int = 1,
    keyword: str = "",
    order: str = "pubdate",
    *,
    auth=None,
    reqtype="app",
    **kwargs,
):
    """
    获取用户投该视频信息

    :param uid: 用户 UID
    :param tid: 分区 ID
    :param pn: 页码
    :param keyword: 搜索关键词
    :param order: 排序方式，可以为 “pubdate(上传日期从新到旧), stow(收藏从多到少), click(播放量从多到少)”
    """
    url = f"{BASE_URL}/x/space/arc/search"
    params = {
        "mid": uid,
        "ps": 30,
        "tid": tid,
        "pn": pn,
        "keyword": keyword,
        "order": order,
    }
    return await get(url, params=params, auth=auth, reqtype=reqtype, **kwargs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/distribution/v1/distribution.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/bilibili/app/distribution/v1/distribution.proto\x12\x1c\x62ilibili.app.distribution.v1\x1a\x19google/protobuf/any.proto\"\xba\x01\n\x14GetUserPreferenceReq\x12\x10\n\x08type_url\x18\x01 \x03(\t\x12[\n\rextra_context\x18\x02 \x03(\x0b\x32\x44.bilibili.app.distribution.v1.GetUserPreferenceReq.ExtraContextEntry\x1a\x33\n\x11\x45xtraContextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"=\n\x16GetUserPreferenceReply\x12#\n\x05value\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\"\xd2\x01\n\x14SetUserPreferenceReq\x12(\n\npreference\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\x12[\n\rextra_context\x18\x02 \x03(\x0b\x32\x44.bilibili.app.distribution.v1.SetUserPreferenceReq.ExtraContextEntry\x1a\x33\n\x11\x45xtraContextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x18\n\x16SetUserPreferenceReply\"\x13\n\x11UserPreferenceReq\"?\n\x13UserPreferenceReply\x12(\n\npreference\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\"U\n\tBoolValue\x12\r\n\x05value\x18\x01 \x01(\x08\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\x08\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t\"V\n\nBytesValue\x12\r\n\x05value\x18\x01 \x01(\x0c\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\x0c\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t\"W\n\x0b\x44oubleValue\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\x01\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t\"V\n\nFloatValue\x12\r\n\x05value\x18\x01 \x01(\x02\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\x02\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t\"V\n\nInt32Value\x12\r\n\x05value\x18\x01 \x01(\x05\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\x05\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t\"V\n\nInt64Value\x12\r\n\x05value\x18\x01 \x01(\x03\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\x03\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t\"W\n\x0bStringValue\x12\r\n\x05value\x18\x01 \x01(\t\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\t\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t\"W\n\x0bUInt32Value\x12\r\n\x05value\x18\x01 \x01(\r\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\r\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t\"W\n\x0bUInt64Value\x12\r\n\x05value\x18\x01 \x01(\x04\x12\x15\n\rlast_modified\x18\x02 \x01(\x03\x12\x15\n\rdefault_value\x18\x03 \x01(\x04\x12\x0b\n\x03\x65xp\x18\x04 \x01(\t2\x82\x03\n\x0c\x44istribution\x12}\n\x11GetUserPreference\x12\x32.bilibili.app.distribution.v1.GetUserPreferenceReq\x1a\x34.bilibili.app.distribution.v1.GetUserPreferenceReply\x12}\n\x11SetUserPreference\x12\x32.bilibili.app.distribution.v1.SetUserPreferenceReq\x1a\x34.bilibili.app.distribution.v1.SetUserPreferenceReply\x12t\n\x0eUserPreference\x12/.bilibili.app.distribution.v1.UserPreferenceReq\x1a\x31.bilibili.app.distribution.v1.UserPreferenceReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.distribution.v1.distribution_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETUSERPREFERENCEREQ_EXTRACONTEXTENTRY._options = None
  _GETUSERPREFERENCEREQ_EXTRACONTEXTENTRY._serialized_options = b'8\001'
  _SETUSERPREFERENCEREQ_EXTRACONTEXTENTRY._options = None
  _SETUSERPREFERENCEREQ_EXTRACONTEXTENTRY._serialized_options = b'8\001'
  _globals['_GETUSERPREFERENCEREQ']._serialized_start=109
  _globals['_GETUSERPREFERENCEREQ']._serialized_end=295
  _globals['_GETUSERPREFERENCEREQ_EXTRACONTEXTENTRY']._serialized_start=244
  _globals['_GETUSERPREFERENCEREQ_EXTRACONTEXTENTRY']._serialized_end=295
  _globals['_GETUSERPREFERENCEREPLY']._serialized_start=297
  _globals['_GETUSERPREFERENCEREPLY']._serialized_end=358
  _globals['_SETUSERPREFERENCEREQ']._serialized_start=361
  _globals['_SETUSERPREFERENCEREQ']._serialized_end=571
  _globals['_SETUSERPREFERENCEREQ_EXTRACONTEXTENTRY']._serialized_start=244
  _globals['_SETUSERPREFERENCEREQ_EXTRACONTEXTENTRY']._serialized_end=295
  _globals['_SETUSERPREFERENCEREPLY']._serialized_start=573
  _globals['_SETUSERPREFERENCEREPLY']._serialized_end=597
  _globals['_USERPREFERENCEREQ']._serialized_start=599
  _globals['_USERPREFERENCEREQ']._serialized_end=618
  _globals['_USERPREFERENCEREPLY']._serialized_start=620
  _globals['_USERPREFERENCEREPLY']._serialized_end=683
  _globals['_BOOLVALUE']._serialized_start=685
  _globals['_BOOLVALUE']._serialized_end=770
  _globals['_BYTESVALUE']._serialized_start=772
  _globals['_BYTESVALUE']._serialized_end=858
  _globals['_DOUBLEVALUE']._serialized_start=860
  _globals['_DOUBLEVALUE']._serialized_end=947
  _globals['_FLOATVALUE']._serialized_start=949
  _globals['_FLOATVALUE']._serialized_end=1035
  _globals['_INT32VALUE']._serialized_start=1037
  _globals['_INT32VALUE']._serialized_end=1123
  _globals['_INT64VALUE']._serialized_start=1125
  _globals['_INT64VALUE']._serialized_end=1211
  _globals['_STRINGVALUE']._serialized_start=1213
  _globals['_STRINGVALUE']._serialized_end=1300
  _globals['_UINT32VALUE']._serialized_start=1302
  _globals['_UINT32VALUE']._serialized_end=1389
  _globals['_UINT64VALUE']._serialized_start=1391
  _globals['_UINT64VALUE']._serialized_end=1478
  _globals['_DISTRIBUTION']._serialized_start=1481
  _globals['_DISTRIBUTION']._serialized_end=1867
# @@protoc_insertion_point(module_scope)
